<p align="center">
  <img width="491" alt="basata" src="https://github.com/sg-tarek/BASATA/blob/main/logo.png">
</p>


Installing
============

.. code-block:: bash

    pip install basata

Usage
=====

.. code-block:: bash

    from basata import basata